@@ -21,7 +21,7 @@ main()
 	unsigned short  i;
 	unsigned short  code;
 
-	if(gets(str)==NULL) break;
+	if(fgets(str, sizeof(str), stdin)==NULL) break;
 	
 	for(d=0, cp=str; ;d++){
 	    if(*cp++!='*') break;
