@@ -7,7 +7,7 @@
 ;;         Dan Rich <drich@morpheus.corp.sgi.com>
 ;; Maintainer: MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Created: 1995/12/15
-;; Version: $Id: tm-image.el,v 7.28 1997/02/13 04:39:19 morioka Exp $
+;; Version: $Id: tm-image.el,v 7.29 1997/03/10 13:12:15 morioka Exp $
 
 ;; Keywords: image, picture, X-Face, MIME, multimedia, mail, news
 
@@ -90,7 +90,7 @@
        ;;
        ;; X-Face
        ;;
-       (if (file-installed-p uncompface-program exec-path)
+       (if (exec-installed-p uncompface-program)
 	   (add-hook 'mime-viewer/content-header-filter-hook
 		     'x-face-decode-message-header)
 	 )
