@@ -1,10 +1,10 @@
 ;;; tm-view.el --- interactive MIME viewer for GNU Emacs
 
-;; Copyright (C) 1995,1996 Free Software Foundation, Inc.
+;; Copyright (C) 1995,1996,1997 Free Software Foundation, Inc.
 
 ;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Created: 1994/7/13 (1994/8/31 obsolete tm-body.el)
-;; Version: $Revision: 7.77 $
+;; Version: $Revision: 7.82 $
 ;; Keywords: mail, news, MIME, multimedia
 
 ;; This file is part of tm (Tools for MIME).
@@ -42,7 +42,7 @@
 ;;;
 
 (defconst mime-viewer/RCS-ID
-  "$Id: tm-view.el,v 7.77 1996/09/23 13:15:09 morioka Exp $")
+  "$Id: tm-view.el,v 7.82 1997/02/18 10:51:17 tmorioka Exp $")
 
 (defconst mime-viewer/version (get-version-string mime-viewer/RCS-ID))
 (defconst mime/viewer-version mime-viewer/version)
@@ -380,6 +380,9 @@ Each elements are regexp of field-name. [tm-view.el]")
 
 (defvar mime-viewer/following-method-alist nil)
 
+(defvar mime-viewer/following-required-fields-list
+  '("From"))
+
 
 ;;; @@ X-Face
 ;;;
@@ -729,14 +732,20 @@ The compressed face will be piped to this command.")
 (defun mime-viewer/define-keymap (&optional mother)
   (let ((mime/viewer-mode-map (if mother
 				  (copy-keymap mother)
-				(make-keymap))))
-    (suppress-keymap mime/viewer-mode-map)
+				(make-keymap)
+				)))
+    (or mother
+	(suppress-keymap mime/viewer-mode-map))
     (define-key mime/viewer-mode-map
       "u"        (function mime-viewer/up-content))
     (define-key mime/viewer-mode-map
       "p"        (function mime-viewer/previous-content))
     (define-key mime/viewer-mode-map
       "n"        (function mime-viewer/next-content))
+    (define-key mime/viewer-mode-map
+      "\e\t"     (function mime-viewer/previous-content))
+    (define-key mime/viewer-mode-map
+      "\t"       (function mime-viewer/next-content))
     (define-key mime/viewer-mode-map
       " "        (function mime-viewer/scroll-up-content))
     (define-key mime/viewer-mode-map
@@ -750,7 +759,7 @@ The compressed face will be piped to this command.")
     (define-key mime/viewer-mode-map
       "v"        (function mime-viewer/play-content))
     (define-key mime/viewer-mode-map
-      "e"	   (function mime-viewer/extract-content))
+      "e"        (function mime-viewer/extract-content))
     (define-key mime/viewer-mode-map
       "\C-c\C-p" (function mime-viewer/print-content))
     (define-key mime/viewer-mode-map
@@ -805,11 +814,10 @@ key		feature
 ---		-------
 
 u		Move to upper content
-p		Move to previous content
-n		Move to next content
+p or M-TAB	Move to previous content
+n or TAB	Move to next content
 SPC		Scroll up or move to next content
-M-SPC		Scroll down or move to previous content
-DEL		Scroll down or move to previous content
+M-SPC or DEL	Scroll down or move to previous content
 RET		Move to next line
 M-RET		Move to previous line
 v		Decode current content as `play mode'
@@ -981,10 +989,34 @@ button-2	Move to point under the mouse cursor
 		      rcnum (cdr rcnum))
 		)
 	      )
+	    (let ((rest mime-viewer/following-required-fields-list))
+	      (while rest
+		(let ((field-name (car rest)))
+		  (or (std11-field-body field-name)
+		      (insert
+		       (format
+			(concat field-name
+				": "
+				(save-excursion
+				  (set-buffer the-buf)
+				  (set-buffer mime::preview/mother-buffer)
+				  (set-buffer mime::preview/article-buffer)
+				  (std11-field-body field-name)
+				  )
+				"\n")))
+		      ))
+		(setq rest (cdr rest))
+		))
 	    (mime/decode-message-header)
 	    )
-	  (funcall (cdr (assq mode mime-viewer/following-method-alist))
-		   new-buf)
+	  (let ((f (cdr (assq mode mime-viewer/following-method-alist))))
+	    (if (functionp f)
+		(funcall f new-buf)
+	      (message
+	       (format
+		"Sorry, following method for %s is not implemented yet."
+		mode))
+	      ))
 	  ))))
 
 (defun mime-viewer/display-x-face ()
@@ -1025,7 +1057,7 @@ button-2	Move to point under the mouse cursor
 	 (i (- (length pcl) 1))
 	 beg)
     (catch 'tag
-      (while (>= i 0)
+      (while (> i 0)
 	(setq beg (mime::preview-content-info/point-min (nth i pcl)))
 	(if (> p beg)
 	    (throw 'tag (goto-char beg))
